---
title: <span class="badge object-type-scalar"></span> PebibytesPerSecond
---
# <span class="badge object-type-scalar"></span> PebibytesPerSecond

Data rate: pebibytes/sec

## Definition

```python
# Data rate: pebibytes/sec
PebibytesPerSecond: typing.Literal["PiBs"] = "PiBs"
```
